import { ComponentDidAppearEvent, ComponentDidDisappearEvent, CommandCompletedEvent, ModalAttemptedToDismissEvent, ModalDismissedEvent, ScreenPoppedEvent, BottomTabSelectedEvent, BottomTabPressedEvent, BottomTabLongPressedEvent, NavigationButtonPressedEvent, SearchBarUpdatedEvent, PreviewCompletedEvent, SearchBarCancelPressedEvent } from 'react-native-navigation';
/**
 * Registers listener to be called each time component appears on screen (attached to the view hierarchy)
 * [more info](https://wix.github.io/react-native-navigation/api/events/#componentdidappear)
 */
declare function useNavigationComponentDidAppear(
/**
 * Function called each time the event is triggered.
 */
handler: (event: ComponentDidAppearEvent) => void, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId?: string): void;
/**
 * Registers listener to be called each time component disappears from screen (detached from the view heirarchy) * [more info](https://wix.github.io/react-native-navigation/api/events/#componentdiddisappear)
 */
declare function useNavigationComponentDidDisappear(
/**
 * Function called each time the event is triggered.
 */
handler: (event: ComponentDidDisappearEvent) => void, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId?: string): void;
/**
 * Registers listener to be called when a Navigation command (i.e push, pop, showModal etc) is invoked.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#registercommandlistener)
 */
declare function useNavigationCommand(
/**
 * Function called each time the event is triggered.
 */
handler: (name: string, params: any) => void, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
commandName?: string): void;
/**
 * Registers listener to be called when a command finishes executing in native. If the command contains
 * animations, for example pushed screen animation) the listener is invoked after the animation ends.
 * [more info]https://wix.github.io/react-native-navigation/api/events/#registercommandcompletedlistener)
 */
declare function useNavigationCommandComplete(
/**
 * Function called each time the event is triggered.
 */
handler: (event: CommandCompletedEvent) => void, 
/**
 * Name of the executed navegation command. Ex. "push".
 */
commandName?: string): void;
/**
 * Registers listener to be called only on iOS pageSheet modal when swipeToDismiss flag is set to true and modal * swiped down to dismiss.
 * [more info](https://wix.github.io/react-native-navigation/apievents#registermodalattemptedtodismisslistenerios-13-only)
 */
declare function useNavigationModalAttemptedToDismiss(
/**
 * Function called each time the event is triggered.
 */
handler: (event: ModalAttemptedToDismissEvent) => void, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId?: string): void;
/**
 * Registers listener to be called when modal is dismissed.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#registermodaldismissedlistener)
 */
declare function useNavigationModalDismiss(
/**
 * Function called each time the event is triggered.
 */
handler: (event: ModalDismissedEvent) => void, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId?: string): void;
/**
 * Registers listener to be called when screen is popped.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#registerscreenpoppedlistener)
 */
declare function useNavigationScreenPop(
/**
 * Function called each time the event is triggered.
 */
handler: (event: ScreenPoppedEvent) => void, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId?: string): void;
/**
 * Registers listener to be called when a BottomTab is selected by the user.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#registerbottomtabselectedlistener)
 */
declare function useNavigationBottomTabSelect(
/**
 * Function called each time the event is triggered.
 */
handler: (event: BottomTabSelectedEvent) => void): void;
/**
 * Registers listener to be called when a BottomTab is pressed by the user.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#registerbottomtabpressedlistener)
 */
declare function useNavigationBottomTabPress(
/**
 * Function called each time the event is triggered.
 */
handler: (event: BottomTabPressedEvent) => void): void;
/**
 * Registers listener to be called when a BottomTab is long pressed by the user.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#registerbottomtablongpressedlistener)
 */
declare function useNavigationBottomTabLongPress(
/**
 * Function called each time the event is triggered.
 */
handler: (event: BottomTabLongPressedEvent) => void): void;
/**
 * Registers listener to be called when a TopBar button is pressed by the user.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#navigationbuttonpressed-event)
 */
declare function useNavigationButtonPress(
/**
 * Function called each time the event is triggered.
 */
handler: (event: NavigationButtonPressedEvent) => void, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId?: string, 
/**
 * Navigation button reference id.
 */
buttonId?: string): void;
/**
 * Registers listener to be called when a SearchBar from NavigationBar gets updated.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#searchbarupdated-ios-11-only)
 */
declare function useNavigationSearchBarUpdate(
/**
 * Function called each time the event is triggered.
 */
handler: (event: SearchBarUpdatedEvent) => void, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId?: string): void;
/**
 * Registers listener to be called when the cancel button on the SearchBar from NavigationBar gets pressed.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#searchbarcancelpressed-ios-11-only)
 */
declare function useNavigationSearchBarCancelPress(
/**
 * Function called each time the event is triggered.
 */
handler: (event: SearchBarCancelPressedEvent) => void, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId?: string): void;
/**
 * Registers listener to be called when preview peek is completed.
 * [more info](https://wix.github.io/react-native-navigation/api/events/#previewcompleted-ios-114-only)
 */
declare function useNavigationPreviewComplete(
/**
 * Function called each time the event is triggered.
 */
handler: (event: PreviewCompletedEvent) => void, 
/**
 * Component reference id. If provided it listens for event only for this screen.
 */
componentId?: string): void;
export { useNavigationComponentDidAppear, useNavigationComponentDidDisappear, useNavigationCommand, useNavigationCommandComplete, useNavigationModalAttemptedToDismiss, useNavigationModalDismiss, useNavigationScreenPop, useNavigationBottomTabSelect, useNavigationBottomTabPress, useNavigationBottomTabLongPress, useNavigationButtonPress, useNavigationSearchBarUpdate, useNavigationSearchBarCancelPress, useNavigationPreviewComplete, };
//# sourceMappingURL=index.d.ts.map